@@ -34,13 +34,17 @@
 #'     \item{gamma: }{coefficient estimates of exposure (X) --> outcome (Y) (total effect).}
 #'     \item{alpha*beta: }{mediation effect.}
 #'     \item{\% total effect: }{alpha*beta / gamma. Percentage of the mediation effect out of the total effect.}
-#'     \item{adjusted.p: }{statistical significance of the mediator (Bonferroni procedure).}
+#'     \item{Bonferroni.p: }{statistical significance of the mediator (Bonferroni procedure).}
 #'     \item{BH.FDR: }{statistical significance of the mediator (Benjamini-Hochberg procedure).}
 #' }
-#'
+#' 
+#' @references Zhang H, Zheng Y, Zhang Z, Gao T, Joyce B, Yoon G, Zhang W, Schwartz J, Just A, Colicino E, Vokonas P, Zhao L, 
+#' Lv J, Baccarelli A, Hou L, Liu L. Estimating and Testing High-dimensional Mediation Effects in Epigenetic Studies. 
+#' Bioinformatics. 2016. DOI: 10.1093/bioinformatics/btw351. PubMed PMID: 27357171.
+#' 
 #' @examples
-#' n <- 100  # sample size
-#' p <- 500 # the dimension of covariates
+#' n <- 200  # sample size
+#' p <- 200 # the dimension of covariates
 #' 
 #' # the regression coefficients alpha (exposure --> mediators)
 #' alpha <- rep(0, p) 
@@ -66,12 +70,12 @@
 #' # Run HIMA with MCP penalty by default
 #' # When Y is continuous (default)
 #' hima.fit <- hima(simdat_cont$X, simdat_cont$Y, simdat_cont$M, verbose = TRUE) 
-#' head(hima.fit)
+#' hima.fit
 #' 
 #' # When Y is binary (should specify family)
 #' hima.logistic.fit <- hima(simdat_bin$X, simdat_bin$Y, simdat_bin$M, 
 #' family = "binomial", verbose = TRUE) 
-#' head(hima.logistic.fit)
+#' hima.logistic.fit
 #' 
 #' @export
 hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM, 
@@ -178,7 +182,7 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     #########################################################################
     ################################ STEP 3 #################################
     #########################################################################
-    if(verbose) message("Step 3: Joint significance test ...", "     (", Sys.time(), ")")
+    message("Step 3: Joint significance test ...", "     (", Sys.time(), ")")
     
     alpha_est_ID_test <- as.numeric(alpha[1, ])  #  the estimator for alpha
     P_adjust_alpha <- length(ID_test) * alpha[2, ]  # the adjusted p-value for alpha (bonferroni)
@@ -220,7 +224,7 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     
     results <- data.frame(alpha = alpha_est, beta = beta_est, gamma = gamma_est, 
                           `alpha*beta` = ab_est, `% total effect` = ab_est/gamma_est * 100, 
-                          `adjusted.p` = P_value, `BH.FDR` = FDR, check.names = FALSE)
+                          `Bonferroni.p` = P_value, `BH.FDR` = FDR, check.names = FALSE)
     
     message("Done!", "     (", Sys.time(), ")")
     
